Learn R Programming

lineupjs (version 4.6.0)

lineupBuilder: lineup builder pattern function

Description

lineup builder pattern function

Usage

lineupBuilder(data, options = c(.lineupDefaultOptions), ranking = NULL, ...)

Value

lineup builder object

Arguments

data

data frame like object i.e. also crosstalk shared data frame

options

LineUp options

ranking

ranking definition created using lineupRanking

...

additional ranking definitions like 'ranking1=...' due to restrictions in converting parameters

LineUp options

filterGlobally

whether filter within one ranking applies to all rankings (default: TRUE)

singleSelection

restrict to single item selection (default: FALSE

noCriteriaLimits

allow more than one sort and grouping criteria (default: FALSE)

animated

use animated transitions (default: TRUE)

sidePanel

show side panel (TRUE, FALSE, 'collapsed') (default: 'collapsed')

hierarchyIndicator

show sorting and grouping hierarchy indicator (TRUE, FALSE) (default: TRUE)

labelRotation

how many degrees should a label be rotated in case of narrow columns (default: 0)

summaryHeader

show summary histograms in the header (default: TRUE)

overviewMode

show overview mode in Taggle by default (default: FALSE)

expandLineOnHover

expand to full row height on mouse over (default: FALSE)

defaultSlopeGraphMode

default slope graph mode: item,band (default: 'item')

ignoreUnsupportedBrowser

ignore unsupported browser detection at own risk (default: FALSE)

rowHeight

height of a row in pixel (default: 18)

rowPadding

padding between two rows in pixel (default: 2)

groupHeight

height of an aggregated group in pixel (default: 40)

groupPadding

padding between two groups in pixel (default: 5)

Examples

Run this code
if (FALSE) {
lineupBuilder(iris) |> buildLineUp()
}

Run the code above in your browser using DataLab