lineup builder pattern function
lineupBuilder(data, options = c(.lineupDefaultOptions), ranking = NULL, ...)lineup builder object
data frame like object i.e. also crosstalk shared data frame
LineUp options
ranking definition created using lineupRanking
additional ranking definitions like 'ranking1=...' due to restrictions in converting parameters
whether filter within one ranking applies to all rankings (default: TRUE)
restrict to single item selection (default: FALSE
allow more than one sort and grouping criteria (default: FALSE)
use animated transitions (default: TRUE)
show side panel (TRUE, FALSE, 'collapsed') (default: 'collapsed')
show sorting and grouping hierarchy indicator (TRUE, FALSE) (default: TRUE)
how many degrees should a label be rotated in case of narrow columns (default: 0)
show summary histograms in the header (default: TRUE)
show overview mode in Taggle by default (default: FALSE)
expand to full row height on mouse over (default: FALSE)
default slope graph mode: item,band (default: 'item')
ignore unsupported browser detection at own risk (default: FALSE)
height of a row in pixel (default: 18)
padding between two rows in pixel (default: 2)
height of an aggregated group in pixel (default: 40)
padding between two groups in pixel (default: 5)
if (FALSE) {
lineupBuilder(iris) |> buildLineUp()
}
Run the code above in your browser using DataLab